sgl-project--sglang
94057c3d3e
PR Test (NPU) / check-changes (push) Has been cancelled
PR Test (NPU) / pr-gate (push) Has been cancelled
PR Test (NPU) / set-image-config (push) Has been cancelled
PR Test (NPU) / stage-b-test-1-npu-a2 (0) (push) Has been cancelled
PR Test (NPU) / stage-b-test-1-npu-a2 (1) (push) Has been cancelled
PR Test (NPU) / stage-b-test-2-npu-a2 (0) (push) Has been cancelled
PR Test (NPU) / stage-b-test-2-npu-a2 (1) (push) Has been cancelled
PR Test (NPU) / stage-b-test-4-npu-a3 (push) Has been cancelled
PR Test (NPU) / stage-b-test-16-npu-a3 (push) Has been cancelled
PR Test (NPU) / multimodal-gen-test-1-npu-a3 (push) Has been cancelled
PR Test (NPU) / multimodal-gen-test-2-npu-a3 (push) Has been cancelled
PR Test (Arm64) / pr-gate (push) Has been cancelled
PR Test (Arm64) / check-changes (push) Has been cancelled
PR Test (Arm64) / build-test (push) Has been cancelled
PR Test (sgl-router) / gate (push) Has been cancelled
PR Test (sgl-router) / tier-1 — lint (push) Has been cancelled
PR Test (sgl-router) / tier-2 — build + test (push) Has been cancelled
PR Test (sgl-router) / tier-3 — docker (placeholder) (push) Has been cancelled
PR Test (sgl-router) / tier-3 — k8s integration (push) Has been cancelled
PR Test (sgl-router) / tier-3 — e2e (push) Has been cancelled
PR Test (sgl-router) / finish (push) Has been cancelled
PR Test (NPU) / single-node-poc (map[name:qwen3_6_27b_w8a8_1p_in64k_out1k_50ms runner:linux-aarch64-a3-2 test_case:test/registered/ascend/performance/qwen3_6_27b/test_npu_qwen3_6_27b_w8a8_1p_in64k_out1k_50ms.py test_type:perf]) (push) Has been cancelled
PR Test (NPU) / pr-test-npu-finish (push) Has been cancelled
PR Test (Xeon) / pr-gate (push) Has been cancelled
PR Test (Xeon) / check-changes (push) Has been cancelled
PR Test (Xeon) / build-test (, xeon-gnr, base-b-test-cpu) (push) Has been cancelled
PR Test (XPU) / check-changes (push) Has been cancelled
PR Test (XPU) / pr-gate (push) Has been cancelled
PR Test (XPU) / stage-a-test-1-gpu-xpu (push) Has been cancelled
PR Test (XPU) / wait-for-stage-a (push) Has been cancelled
PR Test (XPU) / stage-b-test-1-gpu-xpu (push) Has been cancelled
PR Test (XPU) / finish (push) Has been cancelled
CI Model Inventory / build-inventory (push) Has been cancelled
Lint / lint (push) Has been cancelled
PR Benchmark (SMG Components) / Benchmark Compilation Check (push) Has been cancelled
PR Benchmark (SMG Components) / Benchmark - Manual Policy (push) Has been cancelled
PR Benchmark (SMG Components) / Benchmark - Request Processing (push) Has been cancelled
PR Benchmark (SMG Components) / Benchmark Summary (push) Has been cancelled
PR Test (SMG) / build-wheel (push) Has been cancelled
Release SGLang Model Gateway to PyPI / build on windows (x86_64 - auto) (push) Has been cancelled
Release SGLang Model Gateway to PyPI / build on macos (x86_64 - auto) (push) Has been cancelled
PR Test (SMG) / python-unit-tests (push) Has been cancelled
PR Test (SMG) / unit-tests (push) Has been cancelled
PR Test (SMG) / benchmarks (push) Has been cancelled
PR Test (SMG) / chat-completions (push) Has been cancelled
PR Test (SMG) / chat-completions-4gpu (push) Has been cancelled
PR Test (SMG) / e2e (push) Has been cancelled
PR Test (SMG) / docker-build-test (push) Has been cancelled
PR Test (SMG) / k8s-integration (push) Has been cancelled
PR Test (SMG) / finish (push) Has been cancelled
PR Test (SMG) / summarize-benchmarks (push) Has been cancelled
Release SGLang Model Gateway Docker Image / publish (push) Has been cancelled
Release SGLang Model Gateway to PyPI / build on macos (aarch64 - auto) (push) Has been cancelled
Release SGLang Model Gateway to PyPI / build on linux (aarch64 - auto) (push) Has been cancelled
Release SGLang Model Gateway to PyPI / build on linux (x86_64 - auto) (push) Has been cancelled
Release SGLang Model Gateway to PyPI / build on linux (aarch64 - musllinux_1_1) (push) Has been cancelled
Release SGLang Model Gateway to PyPI / build on linux (x86_64 - musllinux_1_1) (push) Has been cancelled
Release SGLang Model Gateway to PyPI / Build SDist (push) Has been cancelled
Release SGLang Model Gateway to PyPI / Upload to PyPI (push) Has been cancelled
Release SGLang Kernels / build-cu129-matrix (aarch64, 12.9, 3.10, arm-kernel-build-node) (push) Has been cancelled
Release SGLang Kernels / build-cu129-matrix (x86_64, 12.9, 3.10, x64-kernel-build-node) (push) Has been cancelled
Release SGLang Kernels / release-cu129 (push) Has been cancelled
Release SGLang Kernels / build-cu130-matrix (aarch64, 13.0, 3.10, arm-kernel-build-node) (push) Has been cancelled
Release SGLang Kernels / build-cu130-matrix (x86_64, 13.0, 3.10, x64-kernel-build-node) (push) Has been cancelled
Release SGLang Kernels / release-cu130 (push) Has been cancelled
Release SGLang Kernels / build-rocm-matrix (3.10, 700) (push) Has been cancelled
Release SGLang Kernels / build-rocm-matrix (3.10, 720) (push) Has been cancelled
Release SGLang Kernels / release-rocm700 (push) Has been cancelled
Release SGLang Kernels / release-rocm720 (push) Has been cancelled
Release SGLang Kernels / build-musa43 (43, 3.10) (push) Has been cancelled
Release SGLang Kernels / release-musa43 (push) Has been cancelled
106 行
3.1 KiB
Plaintext
106 行
3.1 KiB
Plaintext
#include <ATen/ATen.h>
|
|
#include <ATen/cuda/CUDAContext.h>
|
|
|
|
#ifndef USE_ROCM
|
|
#include "pytorch_extension_utils.h"
|
|
#else
|
|
#include "pytorch_extension_utils_rocm.h"
|
|
#endif
|
|
|
|
// tree_mask: [bs * draft_token_num * draft_token_num]
|
|
// verified_seq_len: [bs]
|
|
// positions: [bs * draft_token_num]
|
|
// retrive_index: [bs, draft_token_num]
|
|
// retrive_next_token: [bs, draft_token_num]
|
|
// retrive_next_sibling: [bs, draft_token_num]
|
|
__global__ void reconstructIndicesFromTreeMask(
|
|
bool* tree_mask,
|
|
int64_t* verified_seq_len,
|
|
int64_t* positions,
|
|
int64_t* retrive_index,
|
|
int64_t* retrive_next_token,
|
|
int64_t* retrive_next_sibling,
|
|
int batch_size,
|
|
int draft_token_num) {
|
|
int bid = blockIdx.x;
|
|
int tid = threadIdx.x;
|
|
|
|
if (bid >= batch_size || tid >= draft_token_num) {
|
|
return;
|
|
}
|
|
int base_offset = draft_token_num * draft_token_num;
|
|
// token_idx: [bid * draft_token_num, (bid + 1) * draft_token_num)
|
|
int token_idx = bid * draft_token_num;
|
|
// tree_mask_idx: [bid * base_offset, (bid + 1) * base_offset)
|
|
int tree_mask_offset = bid * base_offset;
|
|
|
|
int depth = 0;
|
|
int parent_idx = -1;
|
|
|
|
for (int i = tid - 1, start_idx = tree_mask_offset + tid * draft_token_num; i >= 0; i--) {
|
|
if (tree_mask[start_idx + i]) {
|
|
depth++;
|
|
if (parent_idx == -1) {
|
|
parent_idx = i;
|
|
}
|
|
}
|
|
}
|
|
retrive_index[token_idx + tid] = token_idx + tid;
|
|
positions[token_idx + tid] = depth + verified_seq_len[bid];
|
|
|
|
int next_token_idx = -1;
|
|
for (int i = tid + 1; i < draft_token_num; i++) {
|
|
if (tree_mask[tree_mask_offset + i * draft_token_num + tid]) {
|
|
next_token_idx = i;
|
|
break;
|
|
}
|
|
}
|
|
retrive_next_token[token_idx + tid] = next_token_idx;
|
|
|
|
int next_sibling_idx = -1;
|
|
if (parent_idx != -1) {
|
|
for (int i = tid + 1; i < draft_token_num; i++) {
|
|
int start_idx = tree_mask_offset + i * draft_token_num + parent_idx;
|
|
if (tree_mask[start_idx]) {
|
|
bool is_sibling = true;
|
|
int end_idx = tree_mask_offset + i * draft_token_num + i;
|
|
for (int j = start_idx + 1; j < end_idx; ++j) {
|
|
if (tree_mask[j]) {
|
|
is_sibling = false;
|
|
break;
|
|
}
|
|
}
|
|
if (is_sibling) {
|
|
next_sibling_idx = i;
|
|
break;
|
|
}
|
|
}
|
|
}
|
|
}
|
|
retrive_next_sibling[token_idx + tid] = next_sibling_idx;
|
|
}
|
|
|
|
void reconstruct_indices_from_tree_mask(
|
|
at::Tensor tree_mask,
|
|
at::Tensor verified_seq_len,
|
|
at::Tensor positions,
|
|
at::Tensor retrive_index,
|
|
at::Tensor retrive_next_token,
|
|
at::Tensor retrive_next_sibling,
|
|
int64_t batch_size,
|
|
int64_t draft_token_num) {
|
|
dim3 grid(batch_size);
|
|
dim3 block(draft_token_num);
|
|
const cudaStream_t stream = at::cuda::getCurrentCUDAStream();
|
|
|
|
reconstructIndicesFromTreeMask<<<grid, block, 0, stream>>>(
|
|
static_cast<bool*>(tree_mask.data_ptr()),
|
|
static_cast<int64_t*>(verified_seq_len.data_ptr()),
|
|
static_cast<int64_t*>(positions.data_ptr()),
|
|
static_cast<int64_t*>(retrive_index.data_ptr()),
|
|
static_cast<int64_t*>(retrive_next_token.data_ptr()),
|
|
static_cast<int64_t*>(retrive_next_sibling.data_ptr()),
|
|
int(batch_size),
|
|
int(draft_token_num));
|
|
}
|